<?php
/**
 * Veroxa functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package veroxa
 */

if ( ! function_exists( 'veroxa_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function veroxa_setup() {

		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 */
		load_theme_textdomain( 'veroxa', get_template_directory() . '/languages' );

		/*
		 * Add default posts and comments RSS feed links to head.
		 */
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * This theme uses wp_nav_menu()
		 */
		register_nav_menus( array(
			'primary'   => esc_html__( 'Primary Menu', 'veroxa' ),
            'secondary' => esc_html__( 'Secondary Menu', 'veroxa' ),
            'social'    => esc_html__( 'Social Menu', 'veroxa' ),
		) );

		/**
		 * Add support for core custom logo.
		 */
		add_theme_support( 'custom-logo', apply_filters( 'veroxa_custom_logo_args', array(
			'width'       => 300,
			'height'      => 90,
			'flex-height' => true,
			'flex-width'  => true,
		) ) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		/*
		 * Set up the WordPress core custom background feature.
		 */
		add_theme_support( 'custom-background', apply_filters( 'veroxa_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

	}
endif;
add_action( 'after_setup_theme', 'veroxa_setup' );

/*
 * Enable support for Post Thumbnails on posts and pages.
 *
 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
 */
function veroxa_add_image_sizes() {

	add_theme_support( 'post-thumbnails' );

	// Set default Post Thumbnail size.
	set_post_thumbnail_size( 1200, 675, array( 'center', 'center' ) );

	// Add different thumbnail sizes
	add_image_size( 'featured', 340, 191, array( 'center', 'center' ) ); // thumbnail index page
	add_image_size( 'thumb', 90, 80, array( 'center', 'center' ) ); // thumbnail related posts

}
add_action( 'after_setup_theme', 'veroxa_add_image_sizes' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function veroxa_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'veroxa_content_width', 800 );
}
add_action( 'after_setup_theme', 'veroxa_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function veroxa_widgets_init() {

	require( 'inc/widgets/recent-posts.php' );
	register_widget( 'mighty_widget_recent_posts' );

	register_sidebar(
		array(
			'name'          => esc_html__( 'Header Widget', 'veroxa' ),
			'id'            => 'headerwidget',
			'description'   => esc_html__( 'Widgets in this area will be shown in the Header.', 'veroxa' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h4>',
			'after_title'   => '</h4>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'After Post', 'veroxa' ),
			'id'            => 'postafter',
			'description'   => esc_html__( 'Widgets in this area will be shown in the after post.', 'veroxa' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h4>',
			'after_title'   => '</h4>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'veroxa' ),
			'id'            => 'sidebar',
			'description'   => esc_html__( 'Widgets in this area will be shown in the sidebar.', 'veroxa' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h4>',
			'after_title'   => '</h4>',
		)
	);

	register_sidebar(
		array(
			'name' 			=> esc_html__( 'Footer Widget Area 1', 'veroxa' ),
			'id' 			=> 'footer-1',
			'description' 	=> esc_html__( 'Appears on all pages at the bottom of site.', 'veroxa' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h4>',
			'after_title'   => '</h4>',
		)
	);

	register_sidebar(
		array(
			'name' 			=> esc_html__( 'Footer Widget Area 2', 'veroxa' ),
			'id' 			=> 'footer-2',
			'description' 	=> esc_html__( 'Appears on all pages at the bottom of site.', 'veroxa' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h4>',
			'after_title'   => '</h4>',
		)
	);

	register_sidebar(
		array(
			'name' 			=> esc_html__( 'Footer Widget Area 3', 'veroxa' ),
			'id' 			=> 'footer-3',
			'description' 	=> esc_html__( 'Appears on all pages at the bottom of site.', 'veroxa' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h4>',
			'after_title'   => '</h4>',
		)
	);

	register_sidebar(
		array(
			'name' 			=> esc_html__( 'Footer Widget Area 4', 'veroxa' ),
			'id' 			=> 'footer-4',
			'description' 	=> esc_html__( 'Appears on all pages at the bottom of site.', 'veroxa' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h4>',
			'after_title'   => '</h4>',
		)
	);

}
add_action( 'widgets_init', 'veroxa_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function veroxa_scripts() {

	// Load Main Stylesheet
	wp_enqueue_style( 'veroxa-stylesheet', get_stylesheet_uri(), array() );
	wp_enqueue_style( 'veroxapro-stylesheetold', get_stylesheet_directory_uri().'/styleold.css', array() );
	
	// Add Google fonts
	wp_enqueue_style( 'veroxapro-fonts', get_template_directory_uri() . '/assets/css/fonts.css', array(), null );

	// Font Awesome
	wp_enqueue_style( 'veroxa-fontawesome', get_template_directory_uri() . '/assets/fontawesome/css/solid.min.css', array(), null );
	wp_enqueue_style( 'veroxa-fontawesomeb', get_template_directory_uri() . '/assets/fontawesome/css/brands.min.css', array(), null );

	// JS file for main navigation
	wp_enqueue_script( 'veroxa-script', get_template_directory_uri() . '/assets/js/navigation.js', array( 'jquery' ), null, true );

	wp_localize_script( 'veroxa-script', 'veroxaScreenReaderText', array(
		'expand'   => __( 'expand child menu', 'veroxa' ),
		'collapse' => __( 'collapse child menu', 'veroxa' ),
	) );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'veroxa_scripts' );

/**
 * Customizer additions.
 */
require_once( 'inc/customizer.php' );

/**
 * Custom template tags for this theme.
 */
require_once( 'inc/template-tags.php' );

/**
 * Load admin theme page.
 */
require_once( 'inc/theme-info.php' );